==> fastapi_tryton-0.1.tar.gz: fastapi_tryton-0.1/setup.py <==
# This file is part of fastapi_tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
import io
import os
import re
from setuptools import setup


def read(fname):
    return io.open(
        os.path.join(os.path.dirname(__file__), fname),
        'r', encoding='utf-8').read()


def get_version():
    init = read('__init__.py')
    return re.search("__version__ = '([0-9.]*)'", init).group(1)


setup(name='fastapi_tryton',
    version=get_version(),
    author='Oscar Alvarez',
    author_email='oscar.alvarez.montero@gmail.com',
    url='https://bitbucket.org/presik/fastapi-tryton',
    description='Adds Tryton support to FastAPI application',
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    py_modules=['fastapi_tryton'],
    zip_safe=False,
    platforms='any',
    keywords='fastapi tryton web',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Tryton',
        'Framework :: FastAPI',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    license='GPL-3',
    python_requires='>=3.7',
    install_requires=[
        'uvicorn',
        'fastapi>=0.74',
        'trytond>=6.0',
    ])

==> fastapi_tryton-0.1.2.tar.gz: fastapi_tryton-0.1.2/setup.py <==
# This file is part of fastapi_tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
import io
import os
import re
from setuptools import setup


def read(fname):
    return io.open(
        os.path.join(os.path.dirname(__file__), fname),
        'r', encoding='utf-8').read()


def get_version():
    init = read('version.py')
    return re.search("__version__ = '([0-9.]*)'", init).group(1)


setup(name='fastapi_tryton',
    version=get_version(),
    author='Oscar Alvarez',
    author_email='oscar.alvarez.montero@gmail.com',
    url='https://bitbucket.org/presik/fastapi-tryton',
    description='Adds Tryton support to FastAPI application',
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    py_modules=['fastapi_tryton', 'version'],
    zip_safe=False,
    platforms='any',
    keywords='fastapi tryton web',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Tryton',
        'Framework :: FastAPI',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    license='GPL-3',
    python_requires='>=3.7',
    install_requires=[
        'uvicorn',
        'fastapi>=0.74',
        'trytond>=6.0',
    ])
